'''OpenGL extension MESA.pixmap_colormap

This module customises the behaviour of the 
OpenGL.raw.GLX.MESA.pixmap_colormap to provide a more 
Python-friendly API

Overview (from the spec)
	
	Since Mesa allows RGB rendering into drawables with PseudoColor,
	StaticColor, GrayScale and StaticGray visuals, Mesa needs a colormap
	in order to compute pixel values during rendering.
	
	The colormap associated with a window can be queried with normal
	Xlib functions but there is no colormap associated with pixmaps.
	
	The glXCreateGLXPixmapMESA function is an alternative to glXCreateGLXPixmap
	which allows specification of a colormap.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/pixmap_colormap.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.MESA.pixmap_colormap import *
from OpenGL.raw.GLX.MESA.pixmap_colormap import _EXTENSION_NAME

def glInitPixmapColormapMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_point_sprite'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_point_sprite',error_checker=_errors._error_checker)
GL_COORD_REPLACE_NV=_C('GL_COORD_REPLACE_NV',0x8862)
GL_POINT_SPRITE_NV=_C('GL_POINT_SPRITE_NV',0x8861)
GL_POINT_SPRITE_R_MODE_NV=_C('GL_POINT_SPRITE_R_MODE_NV',0x8863)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPointParameteriNV(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glPointParameterivNV(pname,params):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_copy_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_copy_buffer',error_checker=_errors._error_checker)
GL_COPY_READ_BUFFER_NV=_C('GL_COPY_READ_BUFFER_NV',0x8F36)
GL_COPY_WRITE_BUFFER_NV=_C('GL_COPY_WRITE_BUFFER_NV',0x8F37)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLintptr,_cs.GLintptr,_cs.GLsizeiptr)
def glCopyBufferSubDataNV(readTarget,writeTarget,readOffset,writeOffset,size):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_QCOM_alpha_test'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_QCOM_alpha_test',error_checker=_errors._error_checker)
GL_ALPHA_TEST_FUNC_QCOM=_C('GL_ALPHA_TEST_FUNC_QCOM',0x0BC1)
GL_ALPHA_TEST_QCOM=_C('GL_ALPHA_TEST_QCOM',0x0BC0)
GL_ALPHA_TEST_REF_QCOM=_C('GL_ALPHA_TEST_REF_QCOM',0x0BC2)
@_f
@_p.types(None,_cs.GLenum,_cs.GLclampf)
def glAlphaFuncQCOM(func,ref):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_AMD_compressed_3DC_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_AMD_compressed_3DC_texture',error_checker=_errors._error_checker)
GL_3DC_XY_AMD=_C('GL_3DC_XY_AMD',0x87FA)
GL_3DC_X_AMD=_C('GL_3DC_X_AMD',0x87F9)

